@@ -33,7 +33,7 @@ def _convert_version(tup):
 
 
 # <
-version_info = (0, 3, 2)
+version_info = (0, 4, 1)
 __version__ = _convert_version(version_info)
 
 del _convert_version
@@ -209,7 +209,13 @@ class ProgramBase(object):
                         else:
                             # add long option based on function name
                             arg.insert(0, '--' + fun_name)
-                    parser.add_argument(*arg, **o['kw'])
+
+                    try:
+                        parser.add_argument(*arg, **o['kw'])
+                    except ValueError:
+                        print('argparse.ProgramBase arg:', repr(arg))
+                        print('argparse.ProgramBase kw:', o['kw'])
+                        raise
             return ssp
 
         def dump(method_name_list, level=0):
@@ -354,9 +360,23 @@ class ProgramBase(object):
                                 sp.add_argument(*arg, **kw)
 
     def _parse_args(self, *args, **kw):
+        tmp_args = args if args else sys.argv[1:]
         name = kw.pop('default_sub_parser', None)
-        if name is not None:
+        if name is not None and '--version' not in tmp_args:
             self._parser.set_default_subparser(name, args=kw.get('args'))
+        if kw.pop('help_all', None):
+            if '--help-all' in tmp_args:
+                try:
+                    self._parser.parse_args(['--help'])
+                except SystemExit:
+                    pass
+                for sc in self._methods_with_sub_parsers:
+                    print('-' * 72)
+                    try:
+                        self._parser.parse_args([sc, '--help'])
+                    except SystemExit:
+                        pass
+                sys.exit(0)
         self._args = self._parser.parse_args(*args, **kw)
         return self._args
 
